/*
 *  ESP8266 - Web Server
 *  
 *  Connect your computer to the Wi-Fi Network "Bonjour_IOT" with "12345678" password
 *  Open your favorite Web browser and enter "192.168.4.1/OFF" to switch off the Builtin LED or
 *  192.168.4.1/ON" to switch it on
 *  
 */
 
#include <ESP8266WiFi.h>

WiFiServer server(80); // Initialize the server on Port 80

int LED_PIN = 2;

void setup() {
  pinMode(LED_PIN, OUTPUT);
  WiFi.mode(WIFI_AP); // Our ESP8266-12E is an AccessPoint
  WiFi.softAP("Hello_IOT", "12345678"); // Provide the SSID and password
  server.begin(); // Start the HTTP Server
  Serial.begin(115200); // Start communication between the ESP8266-12E and the monitor window
  IPAddress HTTPS_ServerIP= WiFi.softAPIP(); // Obtain the IP of the Server
  delay(1000);
  Serial.println();
  Serial.print("Server IP is: "); // Print the IP to the monitor window
  Serial.println(HTTPS_ServerIP);
}

void loop() {
  WiFiClient client = server.available();
  
  if (!client) {
    return;
  }
  
  Serial.println("Somebody has connected :)");
  
  //Read what the browser has sent into a String class and print the request to the monitor
  //String request = client.readString();
  String request = client.readStringUntil('\r');
  
  //Looking under the hood
  Serial.println(request);
  
  // Handle the Request
  if (request.indexOf("/OFF") != -1) digitalWrite(LED_PIN, HIGH);
  else if (request.indexOf("/ON") != -1) digitalWrite(LED_PIN, LOW);
  
  client.flush(); //clear previous info in the stream
  client.print("ok"); // Send the response to the client
  delay(1);
  Serial.println("Client disconnected"); //Looking under the hood          
}
